function [u,raw_u] = simfunc_skewnn(theta,other,dpd)

% this function to simulate from skewn-n copula model

    T = other(1);
    N = other(2);
    seed = other(3);
    
    if strcmp(dpd,'Equidep_theta')
        beta = theta(1)*ones(1,N);
        sig2 = 1;
        lam = theta(2);
        
        s_beta = size(beta);
        if s_beta(2) < s_beta(1)
            beta = beta';
        end

        % Factor simulated series
        zs = zeros(T,1);
        rng(seed,'twister')
        zs(:,1) = sqrt(sig2)*pearsrnd(0,1,lam,3,T,1); % generate skewn-n by Pearson system of distributions

        % Error term series
        eps = zeros(T,N);
        for jj = 1:N
            % rand('state',(jj+1)*seed);
            % randn('state',(jj+1)*seed);
            rng((jj+1)*seed,'twister')
            eps(:,jj) = randn(T,1);
        end
        raw_u  = zs * beta + eps;
        
    elseif strcmp(dpd,'Equidep_beta')
        beta = theta*ones(1,N);
        sig2 = 1;
        lam = -0.5;
        
        s_beta = size(beta);
        if s_beta(2) < s_beta(1)
            beta = beta';
        end
        
        % Factor simulated series
        zs = zeros(T,1);
        rng(seed,'twister')
        zs(:,1) = sqrt(sig2)*pearsrnd(0,1,lam,3,T,1); % generate skewn-n by Pearson system of distributions
        
        % Error term series
        eps = zeros(T,N);
        for jj = 1:N
            % rand('state',(jj+1)*seed);
            % randn('state',(jj+1)*seed);
            rng((jj+1)*seed,'twister')
            eps(:,jj) = randn(T,1);
        end
        raw_u  = zs * beta + eps;
                
    elseif strcmp(dpd,'Block_theta')    
        lam = theta(4);
        
        beta1 = theta(1)*[ones(1,3) zeros(1,7)];
        beta2 = theta(2)*[zeros(1,3) ones(1,3) zeros(1,4)];
        beta3 = theta(3)*[zeros(1,6) ones(1,4)];
        
        s_beta1 = size(beta1);
        if s_beta1(2) < s_beta1(1)
           beta1 = beta1';
        end
        s_beta2 = size(beta2);
        if s_beta2(2) < s_beta2(1)
           beta2 = beta2';
        end
        s_beta3 = size(beta3);
        if s_beta3(2) < s_beta3(1)
            beta3 = beta3';
        end
        
        rng(seed,'twister')
        z = pearsrnd(0,1,lam,3,T,1); % generate skewn-n by Pearson system of distributions
        
        eps = zeros(T,N);
        for i = 1:N
            rand('state',seed*(i+1));
            randn('state',seed*(i+1));
            eps(:,i) = randn(T,1);
        end

        raw_u = z*beta1 + z*beta2 + z*beta3 + eps;
        
    elseif strcmp(dpd,'Block_beta')
        % distributional parameter fixed
        lam = -0.5;
        % theta = factor loadings

        beta1 = theta(1)*[ones(1,3) zeros(1,7)];
        beta2 = theta(2)*[zeros(1,3) ones(1,3) zeros(1,4)];
        beta3 = theta(3)*[zeros(1,6) ones(1,4)];

        s_beta1 = size(beta1);
        if s_beta1(2) < s_beta1(1)
           beta1 = beta1';
        end
        s_beta2 = size(beta2);
        if s_beta2(2) < s_beta2(1)
           beta2 = beta2';
        end
        s_beta3 = size(beta3);
        if s_beta3(2) < s_beta3(1)
            beta3 = beta3';
        end

        rng(seed,'twister')
        z = pearsrnd(0,1,lam,3,T,1); % generate skewn-n by Pearson system of distributions

        eps = zeros(T,N);
        for i = 1:N
            rand('state',seed*(i+1));
            randn('state',seed*(i+1));
            eps(:,i) = randn(T,1);
        end

        raw_u = z*beta1 + z*beta2 + z*beta3 + eps;
    end
    
    u = tiedrank(raw_u)/(T+1);