function [u,raw_u] = simfunc_skewtn(theta,other,dpd)
% Function to simulate skewt-n copula model under Equidependence
    
    T = other(1);
    N = other(2);
    seed = other(3);  
    
    if strcmp(dpd,'Equidep_theta')
        sig2   = 1;
        beta = theta(1)*ones(1,N);
        nu = 1/theta(2);
        lam = theta(3);
        
        s_beta = size(beta);
        if s_beta(2) < s_beta(1)
            beta = beta';
        end

        zs = zeros(T,1);
        zs(:,1) = sqrt(sig2)*skewtdis_rnd2(nu,lam,T,seed)  ; 

        eps = zeros(T,N);
        for i = 1:N
            rand('state',(i+1)*seed);
            randn('state',(i+1)*seed);
            eps(:,i) = randn(T,1);
        end
        raw_u = zs*beta + eps;
        
    elseif strcmp(dpd,'Equidep_beta')
        sig2   = 1;
        beta = theta*ones(1,N);
        nu = 4;
        lam = -0.5;
        
        s_beta = size(beta);
        if s_beta(2) < s_beta(1)
            beta = beta';
        end

        zs = zeros(T,1);
        zs(:,1) = sqrt(sig2)*skewtdis_rnd2(nu,lam,T,seed)  ; 

        eps = zeros(T,N);
        for i = 1:N
            eps(:,i) = skewtdis_rnd2(nu,0,T,(i+1)*seed) ;
        end
        raw_u = zs*beta + eps ;
        
    elseif strcmp(dpd,'Block_theta')
        % distributional parameter fixed
        nu = 1/theta(4);
        lambda = theta(5);

        % theta = factor loadings

        beta1 = theta(1)*[ones(1,3) zeros(1,7)];
        beta2 = theta(2)*[zeros(1,3) ones(1,3) zeros(1,4)];
        beta3 = theta(3)*[zeros(1,6) ones(1,4)];

        s_beta1 = size(beta1);
        if s_beta1(2) < s_beta1(1)
           beta1 = beta1';
        end
        s_beta2 = size(beta2);
        if s_beta2(2) < s_beta2(1)
           beta2 = beta2';
        end
        s_beta3 = size(beta3);
        if s_beta3(2) < s_beta3(1)
            beta3 = beta3';
        end

        z = skewtdis_rnd2(nu,lambda,T,seed);

        eps = zeros(T,N);
        for i = 1:N
            eps(:,i) = skewtdis_rnd2(nu,0,T,seed*(i+1));
        end

        raw_u = z*beta1 + z*beta2 + z*beta3 + eps;        
        
    elseif strcmp(dpd,'Block_beta')
        % distributional parameter fixed
        nu = 4;
        lambda = -0.5;

        % theta = factor loadings

        beta1 = theta(1)*[ones(1,3) zeros(1,7)];
        beta2 = theta(2)*[zeros(1,3) ones(1,3) zeros(1,4)];
        beta3 = theta(3)*[zeros(1,6) ones(1,4)];

        s_beta1 = size(beta1);
        if s_beta1(2) < s_beta1(1)
           beta1 = beta1';
        end
        s_beta2 = size(beta2);
        if s_beta2(2) < s_beta2(1)
           beta2 = beta2';
        end
        s_beta3 = size(beta3);
        if s_beta3(2) < s_beta3(1)
            beta3 = beta3';
        end

        z = skewtdis_rnd2(nu,lambda,T,seed);

        eps = zeros(T,N);
        for i = 1:N
            eps(:,i) = skewtdis_rnd2(nu,0,T,seed*(i+1));
        end

        raw_u = z*beta1 + z*beta2 + z*beta3 + eps;
        
    end
    
u  = tiedrank(raw_u)/(T+1);