%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% The code is to calculate 'true' VaR in test sample period
% Fang Duan
% Last Update on March 2019

clear
addmypath;
%% Parameter setting
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
T = 1500;
N = 5; % N = 10
S = 25;
SizeMonteCarlo = 1000000;
R = 100;

EstimationWindowSize = 1000;
TestWindowStart = EstimationWindowSize + 1;
TestWindow = TestWindowStart : T;
TestWindowSize = T - EstimationWindowSize;

% true DGP
simfunc_true = 'simfunc_skewtt';
theta_null = [1 0.25 -0.5];
dpd = 'Equidep_theta';

% true dynamic parameters in AR-GARCH margin
phi= [0.01, 0.05, 0.05, 0.10, 0.85]; % [\phi_0,\phi_1,\omega,\alpha,\beta]
data_param = repmat(phi, [N,1]);
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% VaR forecasting
pVaR = [0.05 0.01];
VaR0 = NaN(TestWindowSize,length(pVaR),R); % VaR_0.05 and VaR_0.01 for each t in test window 

for index = 1:R
    disp(strcat('Round:',num2str(index)))
    seed = index;
    other = [T N seed];
    % true pseudo number
    uresid = feval(simfunc_true,theta_null,other,dpd);

    % true conditional volatility and residuals
    resid=NaN(T,N); 
    garchdata=NaN(T,N);
    ht = NaN(T,N);
    data=NaN(T,N);
    for dd = 1:N
        resid(:,dd) = norminv(uresid(:,dd),0,1); % innovation assumed to be NORMAL
        [garchdata(:,dd), ht(:,dd)]=tarch_simulate(resid(:,dd),[data_param(dd,3),data_param(dd,4),data_param(dd,5)]',1,0,1,'NORMAL',2); % P=1,O=0,Q=1 leads to GARCH model
        data(:,dd)=armaxfilter_simulate(garchdata(:,dd),data_param(dd,1),1,data_param(dd,2));
    end

    % simulations from true copula model
    data_uresid_sim = feval(simfunc_true, theta_null, [SizeMonteCarlo N 2*seed],dpd);
    data_resid_sim = NaN(SizeMonteCarlo,N);
    for d = 1:N
        data_resid_sim(:,d) = norminv(data_uresid_sim(:,d),0,1);
    end
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
    % obtain the distribution of simulated portfolio return
    for t = TestWindow
        i = t - TestWindowStart + 1;
        disp(strcat('Test Sample:', num2str(i)))

        data_sim = NaN(SizeMonteCarlo,N);
        for ii = 1:SizeMonteCarlo
            for dd = 1:N
                data_sim(ii,dd) = data_param(dd,1) + ...
                                            data_param(dd,2) * data(t-1,dd) +...
                                            sqrt(ht(t,dd)) * data_resid_sim(ii,dd);                
            end
        end
        VaR0(i,:,index) = quantile(log(1+mean(exp(data_sim)-1,2)),pVaR);
    end
end
save(strcat('Workspace_VaR0_N', num2str(N),'.mat'));