function [obj, ghat]= objfunc_SMM(theta,simfunc,other,dpd,momfunc,y,W,q)
% [obj, ghat] = objfunc_SMM(theta,data,simfunc,other,momfunc,W,beta,m)
%
% Function to compute the SMM objective function
%
% INPUTS:   
%           theta, factor loading + the parameter of the copula (must be of the dimenion expected by the specified copula)
%           simfunc, a string containing the name of a function that generates draws from the copula of interest
%           other,optional, a 3x1 vector containing [T,N,seed], the sample size, cross section dimension and RNG seed to use
%           dpd, the dependence structure in margins, e.g., iid or AR(1)-GARCH(1,1)
%           momfunc,optional, a string containing the name of a function that generates a (mx1) vector of moments from the data
%           y, TxN vector of standard uniform data (from original data sample)
%           W,optional, a mxm weight matrix used to combine the M moments,default=eye(m) 
%           q, quantile for which quantile dependence measures is used in estimation
%
% OUTPUTS: 
%           obj, a scalar, the SMM objective function
%           ghat, sizethetax1 vector, ghat used to compute the objective function
%
%  Author: Fang Duan, inspired by Dong Hwan Oh and Andrew J. Patton
%
%  13 April 2019
%
% This code was developed for the following paper:
%
% Duan, F and Manner, H and Wied, D, 2019, "Model and Moment Selection in Factor Copula Models" 

ytilde = feval(simfunc,theta,other,dpd); % simulating data from the copula model at the proposed parameter value
 
mhat = feval(momfunc,y,q); % the vector moments on the original data
mtilde = feval(momfunc,ytilde,q); % the vector of moments on the simulated data

ghat = mhat - mtilde; % the difference between the two vectors of moments
obj = ghat' * W * ghat; % the SMM objective function