function [u raw_u] = simfunc_Clayton(theta,other)
% function [u raw_u] = simfunc_Clayton(theta,s)
%
% Function to simulate data from the Clayton copula
%
% INPUTS:   theta, a strictly positive scalar, the parameter of the Clayton copula
%           other, a 3x1 vector containing other information = [T,N,seed]
%
% OUTPUTS:  u, a TxN matrix of the EDF-transforms of draws from the Clayton copula (used in estimation)
%           raw_u, a TxN matrix of the original draws from the Clayton copula
%
%  Dong Hwan Oh and Andrew J. Patton
%
%  22 October 2013
%
% This code was developed for the following paper:
%
% Oh, D.H. and A.J. Patton, 2013, "Simulated Method of Moments Estimation
% for Copula-Based Multivariate Models," Journal of the American
% Statistical Association, 108(502), 689-700.


T = other(1);
N = other(2);
seed = other(3) ;

rand('state',seed);
randn('state',seed);
raw_u = mvcoprnd('clayton',theta,T,N);

u = tiedrank(raw_u)/(T+1);


