% This file is to generate results of the simultaneous selection frequencies of all combinations of models and moments based on MSC
% the result includes the complete selection frequencies of all true model w.r.t T, N, given pre-determined moments.
% Last edit on Mar 2019
clear
clc

root = '~/Dropbox/MATLAB';
cd(root)
addpath(fullfile(root, 'utils')); % add some functions like matrix2latex.m

rowLabels = repmat({'n-n','t-t','skewn-n','skewt-t'},1,5);
columnLabels = repmat({'n-n','t-t','skewn-n','skewt-t'},1,3);    

J_all = zeros(200,4);
cri = {'bic'};
N = 5;
model_candidate = {'simfunc_gaussian','simfunc_tt','simfunc_skewnn','simfunc_skewtt'};
T_dim = [500 1000 2000];
quantile_set = {'left0','left','tail','central','all'};
dpd_path = 'Equidep_theta';
        
output_horizon = [];
for idx_T = 1:3
    T = T_dim(idx_T);
        output_vertical = [];
        for idx_q = 1:length(quantile_set)
            cd(fullfile(root, strcat('mat/niid_', dpd_path,'_',quantile_set{idx_q})));
            for idx_true = 1:4
                model_true = model_candidate{idx_true};
                for index_model=1:length(model_candidate)
                    if strcmp(model_true, model_candidate{index_model})
                        type = 'Size_niid_';
                    else
                        type = 'Power_niid_';
                    end
                    load(strcat(type,model_true,'_est_by_',model_candidate{index_model},'_T',num2str(T),'_N',num2str(N),'_R200_',dpd_path,'.mat'));                            
                    J_all(:,index_model) = Jstat;
                end
                msc = zeros(200,4);
                if strcmp(cri,'aic')
                    kappa = 2;
                elseif strcmp(cri,'bic')
                    kappa = log(T);
                elseif strcmp(cri,'hqic')
                    kappa = 2.01*log(log(T));
                else
                disp('wrong criterion input')
                end
                if idx_q == 1
                    msc(:,1) = J_all(:,1) - (length(q)-1)*kappa;
                    msc(:,2) = J_all(:,2) - (length(q)-2)*kappa;
                    msc(:,3) = J_all(:,3) - (length(q)-2)*kappa;
                    msc(:,4) = J_all(:,4) - (length(q)-3)*kappa;
                else
                    msc(:,1) = J_all(:,1) - ((length(q)+1)-1)*kappa;
                    msc(:,2) = J_all(:,2) - ((length(q)+1)-2)*kappa;
                    msc(:,3) = J_all(:,3) - ((length(q)+1)-2)*kappa;
                    msc(:,4) = J_all(:,4) - ((length(q)+1)-3)*kappa;
                end  
                min_msc = zeros(200,1);
                for i = 1:200
                    min_msc(i,1) = min(msc(i,:));
                end
                output_cell(:,idx_true) = [mean(min_msc == msc(:,1));
                                                        mean(min_msc == msc(:,2));
                                                        mean(min_msc == msc(:,3)); 
                                                        mean(min_msc == msc(:,4))];                                  
            end
            output_vertical = [output_vertical; output_cell];    
        end
        output_horizon = [output_horizon output_vertical];
end          
cd(root)
matrix2latex(output_horizon,strcat('prob_msc_N', num2str(N),'_fixed_criterion_', cri{1},'.tex'),'rowLabels',rowLabels,'columnLabels',columnLabels,'format','%.3f');